@@ -1,16 +1,24 @@
 from __future__ import annotations
 from copy import deepcopy
 from decimal import Decimal
-from dataclasses import asdict
+from dataclasses import asdict, dataclass
 from shapely.wkt import loads as wkt_loads
-from shapely import Geometry, GeometryCollection, Point, Polygon
+from shapely import (
+    Geometry,
+    GeometryCollection,
+    Point,
+    Polygon,
+    set_precision,
+    LineString,
+)
+import load_distribution as ld
 from papermodels.datatypes.annotation import Annotation
-from papermodels.loads.load_distribution import LoadingGeometry
 from papermodels.geometry import geom_ops
 from papermodels.datatypes.exceptions import LegendError, GeometryError, AnnotationError
 from typing import Any, Optional
 import re
 import numpy as np
+import numpy.typing as npt
 from numpy.typing import ArrayLike
 
 
@@ -34,7 +42,7 @@ def annotation_to_shapely(annot: Annotation) -> Any:
     Returns an shapely geometry created from the annotation type and
     vertices in 'annot'.
     """
-    return wkt_loads(_annotation_to_wkt(annot))
+    return set_precision(wkt_loads(_annotation_to_wkt(annot)), grid_size=1e-3)
 
 
 def get_annotation_geometry_pairs(
@@ -48,13 +56,13 @@ def get_annotation_geometry_pairs(
 
 def parsed_annotations_to_loading_geometry(
     parsed_annots: dict[Annotation, dict],
-) -> list[LoadingGeometry]:
+) -> list[ld.LoadingGeometry]:
     """
     Convert annotations representing loading areas into a list of LoadingArea
     """
     acc = []
     for annot, annot_attrs in parsed_annots.items():
-        lg = LoadingGeometry(
+        lg = ld.LoadingGeometry(
             geometry=annot_attrs["geometry"],
             occupancy=annot_attrs.get("occupancy", None),
             load_components=annot_attrs.get("components", None),
@@ -182,7 +190,7 @@ def _annotation_to_wkt(annot: Annotation) -> str:
     Returns a WKT string representing the geometry in 'annot'. The WKT
     string can be loaded with shapely.wkt.loads (see shapely documentation)
     """
-    if annot.object_type == "PolyLine" or annot.object_type == "Line":
+    if annot.object_type in ("Line", "PolyLine", "LineString"):
         grouped_vertices = geom_ops._group_vertices_str(annot.vertices)
         return f"LINESTRING({grouped_vertices})"
     elif annot.object_type in ("Polygon", "Rectangle", "Square"):
