@@ -190,7 +190,20 @@ def pike_annotation_to_pm_annotation(
     if global_opacity != Decimal("1.0") and line_opacity == Decimal("1.0"):
         line_opacity = global_opacity
     line_width = stream_dict.get("w", (1,))[0]
+
+    line_type = stream_dict.get("d", None)
+    if line_type is not None:
+        line_type = tuple(line_type)
+    # TODO: Fix test suite PDF files so that the linetype is no
+    # longer an issue.
+    # Use the above to get the line_type
+    # Currently the tests use PDF files created with a mixture
+    # of two softwares (Bluebeam Revu and Qoppa PDF Studio)
+    # Activating the line_type breaks the test suite because
+    # some entities are not recognized in the legend anymore
+    # because of small differences in the linetype
     line_type = None
+
     matrix = (1, 0, 0, 1, 0, 0)
 
     annotation = Annotation(
